To be able to handle larger-than-memory files, the SAS file is converted in chunks. It does not check for existing files in the output directory. Existing data will not be overwritten, but might be duplicated if it already exists in the directory, since files are saved with UUIDs in their names.
Examples
sas_file <- fs::path_package("fastreg", "extdata", "test.sas7bdat")
convert_file(
path = sas_file,
output_dir = fs::path_temp("path/to/output/file")
)
#> ✔ Converted test.sas7bdat