This helper function is used for testing fastreg code and in the docs. It will write each element of a named list as a SAS file to the given directory. The file names are determined from the list names.
Examples
save_as_sas(
data_list = simulate_register("bef", "2020"),
path = fs::path_temp()
)